@@ -14,7 +14,7 @@ pub struct RawPacketStream(Arc<AsyncFd<SyncRawPacketStream>>);
 
 impl RawPacketStream {
     pub fn new() -> Result<RawPacketStream> {
-        Ok(SyncRawPacketStream::new()?.into())
+        Ok(SyncRawPacketStream::new()?.try_into()?)
     }
 
     pub fn bind(&mut self, name: &str) -> Result<()> {
@@ -136,8 +136,9 @@ impl<'a> AsyncWrite for &'a RawPacketStream {
     }
 }
 
-impl From<SyncRawPacketStream> for RawPacketStream {
-    fn from(sync: SyncRawPacketStream) -> RawPacketStream {
+impl TryFrom<SyncRawPacketStream> for RawPacketStream {
+    fn try_from(sync: SyncRawPacketStream) -> Result<RawPacketStream> {
+        sync.set_non_blocking()?;
         RawPacketStream(Arc::new(AsyncFd::new(sync).expect("oopsie whoopsie")))
     }
 }
